@@ -170,7 +170,7 @@ class ProtocolFlags(BitField):
 
 	SKIP = 0x400
 
-	REJECTEDT_RECIPIENT = RCPT_REJ = 0x800
+	REJECTED_RECIPIENT = RCPT_REJ = 0x800
 
 	NR_CONNECT = NR_CONN = 0x1000
 	NR_HELO = 0x2000
